@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2013-2016 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2013-2018 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -84,7 +84,7 @@ void Jackrx::init (const char *jname, const char *jserv, const int *clist)
                                          flags | JackPortIsOutput, 0);
     }
     pthread_getschedparam (jack_client_thread_id (_client), &spol, &spar);
-    _rprio = spar.sched_priority -  sched_get_priority_max (spol);
+    _rprio = spar.sched_priority;
     _buff = new float [_bsize * _nchan];
     _state = IDLE;
 }
@@ -216,37 +216,37 @@ void Jackrx::capture (int nframes)
     _resamp.out_data  = _buff;
     while (_resamp.out_count)
     {
-	// Allow the audio queue to underrun, but
-	// use zero valued samples in that case.
-	// This will happen when the sender skips
-	// some cycles and the receiver is not
-	// configured for additional latency.
+        // Allow the audio queue to underrun, but
+        // use zero valued samples in that case.
+        // This will happen when the sender skips
+        // some cycles and the receiver is not
+        // configured for additional latency.
         k1 = _audioq->rd_avail ();
         k2 = _audioq->rd_linav ();
-	if (k1 > 0)
-	{
-	    _resamp.inp_count = (k1 < k2) ? k1 : k2;
-	    _resamp.inp_data  = _audioq->rd_datap ();
-	}
-	else
-	{
-	    _resamp.inp_count = 999999;
-	    _resamp.inp_data = 0;
-	}
-	// Resample up to a full output buffer.
-	k1 = _resamp.inp_count;
-	_resamp.process ();
-	k1 -= _resamp.inp_count;
-	// Adjust audio queue and state by the
+        if (k1 > 0)
+        {
+            _resamp.inp_count = (k1 < k2) ? k1 : k2;
+            _resamp.inp_data  = _audioq->rd_datap ();
+        }
+        else
+        {
+            _resamp.inp_count = 999999;
+            _resamp.inp_data = 0;
+        }
+        // Resample up to a full output buffer.
+        k1 = _resamp.inp_count;
+        _resamp.process ();
+        k1 -= _resamp.inp_count;
+        // Adjust audio queue and state by the
         // number of frames consumed.
-	_audioq->rd_commit (k1);
+        _audioq->rd_commit (k1);
     }
     // Deinterleave _buff to outputs.
     for (j = 0; j < _nchan; j++)
     {
-	p = _buff + j;
-	q = (float *)(jack_port_get_buffer (_ports [j], nframes));
-	for (i = 0; i < _bsize; i++) q [i] = p [i * _nchan];
+        p = _buff + j;
+        q = (float *)(jack_port_get_buffer (_ports [j], nframes));
+        for (i = 0; i < _bsize; i++) q [i] = p [i * _nchan];
     }       
 }
 
@@ -271,13 +271,13 @@ void Jackrx::sendinfo (int state, double error, double ratio, int nfram)
 
     if (_infoq->wr_avail ())
     {
-	I = _infoq->wr_datap ();
-	I->_state = state;
-	I->_error = error;
-	I->_ratio = ratio;
-	I->_nfram = nfram;
-	I->_syncc = _syncnt;
-	_infoq->wr_commit ();
+        I = _infoq->wr_datap ();
+        I->_state = state;
+        I->_error = error;
+        I->_ratio = ratio;
+        I->_nfram = nfram;
+        I->_syncc = _syncnt;
+        _infoq->wr_commit ();
     }
 }
 
@@ -312,14 +312,14 @@ int Jackrx::jack_process (int nframes)
     // Buffer size change, no data, or other evil.
     if (_state >= TXEND)
     {
-	sendinfo (_state, 0, 0, 0);
-	_state = IDLE;
-	return 0;
+        sendinfo (_state, 0, 0, 0);
+        _state = IDLE;
+        return 0;
     }
     // Output silence if idle.
     if (_state < WAIT)
     {
-	silence (nframes);
+        silence (nframes);
         return 0;
     }
 
@@ -327,8 +327,8 @@ int Jackrx::jack_process (int nframes)
     // the WAIT state. Disabled while freewheeling.
     if (_state == WAIT)
     {
-	silence (nframes);
-	if (_freew) return 0;
+        silence (nframes);
+        if (_freew) return 0;
         if (++_count == 0) initsync ();
         else return 0;
     }
@@ -336,14 +336,15 @@ int Jackrx::jack_process (int nframes)
     // Get local timing info.
     jack_get_cycle_times (_client, &ft, &t0, &t1, &usecs);
     _t_j0 = tjack (t0);
+
     if (_first)
     {
-	_first = false;
-	nskip = 0;
+        _first = false;
+        nskip = 0;
     }
     else
     {
-	usecs = (float)(t0 - _tnext);
+        usecs = (float)(t0 - _tnext);
         nskip = (int)(1e-6f * usecs * _fsamp / _ratio + 0.5f);
     }
     _tnext = t1;
@@ -361,45 +362,45 @@ int Jackrx::jack_process (int nframes)
     shift = true;
     while (_timeq->rd_avail ())
     {
-	D = _timeq->rd_datap ();
-	switch (D->_flags)
-	{
-	case Netrx::WAIT:
-	    // Restart synchronisation in case the netrx
-	    // thread signals a problem. This will happen
-	    // when the sender goes into freewheeling mode.
-	    initwait (_ppsec / 2);
-	    return 0;
-	case Netrx::PROC:
+        D = _timeq->rd_datap ();
+        switch (D->_flags)
+        {
+        case Netrx::WAIT:
+            // Restart synchronisation in case the netrx
+            // thread signals a problem. This will happen
+            // when the sender goes into freewheeling mode.
+            initwait (_ppsec / 2);
+            return 0;
+        case Netrx::PROC:
             // Frame count and reception time stamp.
-	    if (_state < SYNC2)
-	    {
-		_state++;
-		sendinfo (_state, 0, 0, 0);
-	    }
-	    if (shift)
-	    {
-		shift = false;
-		_t_a0 = _t_a1;
-		_k_a0 = _k_a1;
-	    }
-	    _k_a1 = D->_count;
-	    _t_a1 = D->_tjack;
-	    break;
-//	case Netrx::TNTP:
-//	    // Frame count and system time at sender.
-//	    procsync (D->_count, D->_tsecs, D->_tfrac);
-//	    break;
-	case Netrx::TERM:
-	    // Sender terminated.
-	    _state = TXEND;
-	    return 0;
-	case Netrx::FAIL:
-	    // Fatal error in netrx thread.
-	    _state = FATAL;
-	    return 0;
-	}
-	_timeq->rd_commit ();
+            if (shift)
+            {
+                shift = false;
+                _t_a0 = _t_a1;
+                _k_a0 = _k_a1;
+                if (_state < SYNC2)
+                {
+                    _state++;
+                    sendinfo (_state, 0, 0, 0);
+                }
+            }
+            _k_a1 = D->_count;
+            _t_a1 = D->_tjack;
+            break;
+//      case Netrx::TNTP:
+//          // Frame count and system time at sender.
+//          procsync (D->_count, D->_tsecs, D->_tfrac);
+//          break;
+        case Netrx::TERM:
+            // Sender terminated.
+            _state = TXEND;
+            return 0;
+        case Netrx::FAIL:
+            // Fatal error in netrx thread.
+            _state = FATAL;
+            return 0;
+        }
+        _timeq->rd_commit ();
     }
 
     err = 0;
@@ -408,7 +409,7 @@ int Jackrx::jack_process (int nframes)
         // Compute the delay error.
         d1 = tjack_diff (_t_j0, _t_a0);
         d2 = tjack_diff (_t_a1, _t_a0);
-	// This must be done as integer as both terms will overflow.
+        // This must be done as integer as both terms will overflow.
         k = _k_a0 - _audioq->nrd ();
         err = k + (_k_a1 - _k_a0) * d1 / d2  + _resamp.inpdist () - _delay;
         if (_state == SYNC2)
@@ -439,21 +440,21 @@ int Jackrx::jack_process (int nframes)
         if (fabs (_z3) > 0.05)
         {
             // Something is really wrong.
-	    // Wait 10 seconds then restart.
+            // Wait 10 seconds then restart.
             initwait (10 * _ppsec);
             return 0;
         }
         _rcorr = 1 - (_z2 + _z3);
-	if (_rcorr > 1.05) _rcorr = 1.05;
-	if (_rcorr < 0.95) _rcorr = 0.95;
+        if (_rcorr > 1.05) _rcorr = 1.05;
+        if (_rcorr < 0.95) _rcorr = 0.95;
         _resamp.set_rratio (_rcorr);
 
-	// Resample and transfer between audio
+        // Resample and transfer between audio
         // queue and jack ports.
-	capture (nframes);
-	k = _audioq->rd_avail ();
-	sendinfo (_state, err, _rcorr, k);
-	if (k < -_limit) _state = TXEND;
+        capture (nframes);
+        k = _audioq->rd_avail ();
+        sendinfo (_state, err, _rcorr, k);
+        if (k < -_limit) _state = TXEND;
     }
     else silence (nframes);
 
@@ -472,16 +473,16 @@ int Jackrx::jack_process (int nframes)
 //     while (_syncq->rd_avail () > 1) _syncq->rd_commit ();
 //     if (_syncq->rd_avail () > 0)
 //     {
-// 	D = _syncq->rd_datap ();
-// 	_tj_ext = D->_tjack;
-// 	_ts_ext = tntp (D->_tsecs, D->_tfrac);
-// 	_syncq->rd_commit ();
+//         D = _syncq->rd_datap ();
+//         _tj_ext = D->_tjack;
+//         _ts_ext = tntp (D->_tsecs, D->_tfrac);
+//         _syncq->rd_commit ();
 //     }
 //     else
 //     {
-// 	_syndel = 0.0;
-// 	_syncnt = 0;
-// 	return;
+//         _syndel = 0.0;
+//         _syncnt = 0;
+//         return;
 //     }
     
 //     ds = tsyst_diff (ts_ref, _ts_ext);
@@ -489,22 +490,22 @@ int Jackrx::jack_process (int nframes)
 //     del = (ds + dj) * _fsamp / _ratio - fc_ref + _k_a0 + _bsize;
 //     if (_syncnt == 0)
 //     {
-// 	_syndel = del;
-// 	_syncnt++;
+//         _syndel = del;
+//         _syncnt++;
 //     }
 //     else if (_syncnt < 10)
 //     {
-// 	_syndel += 0.25 * (del - _syndel);
-// 	_syncnt++;
+//         _syndel += 0.25 * (del - _syndel);
+//         _syncnt++;
 //     }
 //     else
 //     {
-// 	_syndel += 0.025 * (del - _syndel);
+//         _syndel += 0.025 * (del - _syndel);
 //     }
 //     if (_syncnt == 10)
 //     {
-// 	k = (int)(_syndel - _delay);
-// 	if (abs (k) > 500) _audioq->rd_commit (-k);
-// 	_delay = _syndel;
+//         k = (int)(_syndel - _delay);
+//         if (abs (k) > 500) _audioq->rd_commit (-k);
+//         _delay = _syndel;
 //     }
 // }
