@@ -86,7 +86,7 @@ void Jacktx::init (const char *jname, const char *jserv)
     }
 
     pthread_getschedparam (jack_client_thread_id (_client), &spol, &spar);
-    _rtprio = spar.sched_priority -  sched_get_priority_max (spol);
+    _rprio = spar.sched_priority;
 }
 
 
