@@ -48,7 +48,7 @@ public:
     const char *jname (void) const { return _jname; }
     int fsamp (void) const { return _fsamp; }
     int bsize (void) const { return _bsize; }
-    int rtprio (void) const { return _rtprio; }
+    int rprio (void) const { return _rprio; }
 
 private:
 
@@ -67,7 +67,7 @@ private:
     jack_client_t  *_client;
     jack_port_t    *_ports [Netdata::MAXCHAN];
     const char     *_jname;
-    int             _rtprio;
+    int             _rprio;
     int             _nchan;
     int             _fsamp;
     int             _bsize;
