@@ -56,7 +56,7 @@ static int           form_arg  = Netdata::FM_24BIT;
 static void help (void)
 {
     fprintf (stderr, "\n%s-%s\n", APPNAME, VERSION);
-    fprintf (stderr, "(C) 2013-2014 Fons Adriaensen  <fons@linuxaudio.org>\n");
+    fprintf (stderr, "(C) 2013-2016 Fons Adriaensen  <fons@linuxaudio.org>\n");
     fprintf (stderr, "Send audio to zita-n2j.\n\n");
     fprintf (stderr, "Usage: %s <options> ip-address ip-port \n", APPNAME);
     fprintf (stderr, "       %s <options> ip-address ip-port interface\n", APPNAME);
@@ -248,7 +248,7 @@ int main (int ac, char *av [])
     infoq = new Lfq_int32 (16);
 
     descpack.init_audio_desc (0, form_arg, chan_arg, psize, jacktx->fsamp (), jacktx->bsize ());
-    nettx->start (packq, timeq, &descpack, sockfd, jacktx->rtprio () + 5);
+    nettx->start (packq, timeq, &descpack, sockfd, jacktx->rprio () + 5);
     jacktx->start (packq, timeq, infoq, nettx, form_arg, ppper);
 
     signal (SIGINT, siginthandler);
